@@ -19,8 +19,9 @@
 (define (dict args)
   "ask dictionary server"
   (set! args (list->strlist args))
-  (fh-set-current-target-buddy! "dict")  
   (if (= (length args) 0)
       (system "dict --help")
-      (system (string-append "dict -P more " (list->asv args " ")))))
+      (begin
+	(fh-set-current-target-buddy! "dict")  
+	(system (string-append "dict -P more \"" (list->asv args " ") "\"")))))
 
