@@ -26,6 +26,7 @@ SCM ex_message_receive_hook;
 SCM ex_contact_added_hook;
 SCM ex_message_receive_offline_hook;
 SCM ex_login_post_hook;
+SCM ex_mail_notify_hook;
 int hook_return = 0;
 
 int
@@ -70,6 +71,12 @@ get_login_post_hook ()
   return (ex_login_post_hook);
 }
 
+SCM
+get_mail_notify_hook ()
+{
+  return (ex_mail_notify_hook);
+}
+
 void
 install_new_variables (void)
 {
@@ -149,6 +156,18 @@ install_new_hooks (void)
   /* hook: fh-login-post-hook
      is called from
      file: messenger.c
+     function: ext_yahoo_mail_notify (...)
+     with arguments
+     "mail-from" and "mail-subject"
+
+     set the hook like this
+     (add-hook! fh-mail-notify-hook (lambda (from subject) (do-something)))
+   */
+
+  ex_mail_notify_hook = scm_create_hook ("fh-mail-notify-hook", 2);
+  /* hook: fh-mail-notify-hook
+     is called from
+     file: yahoo_backend.c
      function: send_message (...)
      with arguments
      "message-from" and "message-data"
