@@ -33,38 +33,26 @@ int temp_rl_point;
    messages from process_* and handle_yahoo_message in yahoo-adapter.c
    are asynchronous messages 
 */
-#define PRINTF_MESSAGE(format, args...) \
-{ \
-  temp_rl_point = rl_point; \
-  rl_kill_text (0, rl_end); \
-  rl_redisplay (); \
- \
-  printf ("\r" format, ##args); \
- \
-  rl_do_undo (); \
-  rl_point = temp_rl_point; \
-  rl_reset_line_state (); \
-  rl_forced_update_display (); \
-  bell (); \
-}
-
-
-/* use this macro only for exporting to scheme environment.
-   FIXME: still not working. test with proudofhoo.scm
-*/
-#define EX_PRINTF_MESSAGE(format, args...) \
-{ \
-  temp_rl_point = rl_point; \
-  rl_kill_text (0, rl_end); \
-  rl_redisplay (); \
- \
-  printf (format, ##args); \
- \
-  rl_do_undo (); \
-  rl_point = temp_rl_point; \
-  rl_reset_line_state (); \
-  rl_forced_update_display (); \
-  bell (); \
+#define PRINTF_MESSAGE(format, args...)   \
+{                                         \
+  if (rl_end >= 0)                        \
+    {                                     \
+      temp_rl_point = rl_point;           \
+      rl_kill_text (0, rl_end);           \
+      rl_redisplay ();                    \
+    }                                     \
+                                          \
+  printf ("\r" format, ##args);           \
+                                          \
+  if (rl_end >= 0)                        \
+    {                                     \
+      rl_do_undo ();                      \
+      rl_point = temp_rl_point;           \
+      rl_reset_line_state ();             \
+    }                                     \
+                                          \
+  rl_forced_update_display ();            \
+  bell ();                                \
 }
 
 /* defining strcasestr function temporarily */
