@@ -556,7 +556,7 @@ ext_yahoo_status_changed (int id, char *who, int stat, char *msg,
     {
       if (stat == YAHOO_STATUS_CUSTOM)
 	{
-	  if (msg)
+	  if (msg && msg[0])
 	    {
 	      PRINTF_MESSAGE ("%s is now [%s]\n", who, msg);
 	    }
@@ -691,6 +691,9 @@ ext_yahoo_contact_added (int id, char *myid, char *who, char *msg)
                 gh_list (gh_str02scm (who),
                          gh_str02scm (buf),
                          SCM_UNDEFINED));
+  if (get_hook_return () == 1)
+    return;
+
   /*
     yahoo_reject_buddy(id, who, "Thanks, but no thanks.");
   */
@@ -729,8 +732,17 @@ ext_yahoo_mail_notify (int id, char *from, char *subj, int cnt)
     return;
 
   if (from && subj)
-    snprintf (buff, sizeof (buff),
-	      "You have mail from: <%s>, subject: <%s>.\n", from, subj);
+    {
+      snprintf (buff, sizeof (buff),
+		"You have mail from: <%s>, subject: <%s>.\n", from, subj);
+
+      /* Mail notify hook */
+      scm_run_hook (get_mail_notify_hook (),
+		    gh_list (gh_str02scm (from),
+			     gh_str02scm (subj),
+			     SCM_UNDEFINED));
+    }
+
   if (cnt)
     {
       char buff2[100];
